@@ -17,6 +17,11 @@ Open a new shell and launch python and type::
     >>>
 
 '''
+try:
+    import pulsar
+except ImportError: #pragma nocover
+    import sys
+    sys.path.append('../../')
 from random import normalvariate
 
 from pulsar.apps import rpc, wsgi
@@ -46,8 +51,8 @@ def randompaths(request, num_paths=1, size=250, mu=0, sigma=1):
 class RequestCheck:
     
     def __call__(self, request, name):
-        assert(str(request)==name)
-        assert(request.user==None)
+        method = request.rpc.method
+        assert(method==name)
         return True
 
 
