@@ -1,13 +1,20 @@
 import os
 import re
+import time
 import shutil
 import tempfile
 import cProfile as profiler
 import pstats
+from datetime import datetime
 
 import pulsar
+from pulsar.utils.httpurl import ispy3k
 from pulsar.apps import test
-from pulsar.utils.py2py3 import StringIO
+
+if ispy3k:
+    from io import StringIO as Stream
+else:   #pragma    nocover
+    from io import BytesIO as Stream
 
 other_filename = 'unknown'
 line_func = re.compile(r'(?P<line>\d+)\((?P<func>\w+)\)')
@@ -36,27 +43,6 @@ def absolute_file(val):
     dir = os.getcwd()
     return os.path.join(dir,val)
 
-class ProfileOption(test.TestOption):
-    name = 'profile'
-    flags = ["--profile"]
-    action = "store_true"
-    default = False
-    validator = pulsar.validate_bool
-    desc = '''Profile tests using the cProfile'''
-    
-class ProfilePathOption(test.TestOption):
-    name = 'profile_stats_path'
-    flags = ["--profile-stats-path"]
-    default = 'htmlprof'
-    desc = '''location of profile directory'''
-    validator = absolute_file
-    
-    
-def make_header(headers):
-    for h in headers:
-        if h:
-            yield '<p>{0}</p>'.format(h)
-            
 def make_stat_table(data):
     yield "<thead>\n<tr>\n"
     for head, description in headers:
@@ -68,9 +54,8 @@ def make_stat_table(data):
             yield '<td>{0}</td>'.format(col)
         yield '\n</tr>\n'
     yield '</tbody>'
-        
-    
-def data_stream(lines, num = None):
+
+def data_stream(lines, num=None):
     if num:
         lines = lines[:num]
     for line in lines:
@@ -102,21 +87,7 @@ def data_stream(lines, num = None):
             else:
                 new_fields.extend(('', '', other_filename))
             yield new_fields
-    
-    
-class TestProfile(test.WrapTest):
-    
-    def __init__(self, test, dir):
-        self.dir = dir
-        super(TestProfile,self).__init__(test)
-    
-    def _call(self):
-        prof = profiler.Profile()
-        tmp = tempfile.mktemp(dir=self.dir)
-        prof.runcall(self.testMethod)
-        prof.dump_stats(tmp)
-    
-    
+
 def copy_file(filename, target, context=None):
     with open(os.path.join(template_path,filename),'r') as file:
         stream = file.read()
@@ -124,43 +95,60 @@ def copy_file(filename, target, context=None):
         stream = stream.format(context)
     with open(os.path.join(target,filename),'w') as file:
         file.write(stream)
-    
-    
-class Profile(test.Plugin):
-    active = False
-    
+
+
+class Profile(test.TestPlugin):
+    ''':class:`pulsar.apps.test.Plugin` for profiling test cases.'''
+    desc = '''Profile tests using the cProfile'''
+    profile_stats_path = pulsar.Setting(default='htmlprof',
+                                desc='''location of profile directory''',
+                                validator=absolute_file)
+
     def configure(self, cfg):
-        self.active = cfg.profile
+        self.config = cfg
         self.profile_stats_path = cfg.profile_stats_path
         dir, name = os.path.split(self.profile_stats_path)
         fname = '.'+name
         self.profile_temp_path = os.path.join(dir, fname)
+
+    def before_test_function_run(self, test, local):
+        # If active return a TestProfile instance wrapping the real test case.
+        if self.config.profile:
+            local.prof = profiler.Profile()
+            local.tmp = tempfile.mktemp(dir=self.profile_temp_path)
+            local.prof.enable()
         
-    def getTest(self, test):
-        if self.active:
-            return TestProfile(test, self.profile_temp_path)
-    
+    def after_test_function_run(self, test, local, result):
+        if self.config.profile:
+            local.prof.disable()
+            local.prof.dump_stats(local.tmp)
+
     def on_start(self):
-        if self.active:
+        if self.config.profile:
             self.remove_dir(self.profile_temp_path, build=True)
-        
+
     def remove_dir(self, dir, build=False):
+        sleep = 0
         if os.path.exists(dir):
             shutil.rmtree(dir)
+            sleep = 0.2
         if build:
-            os.makedirs(dir)
-        
+            time.sleep(sleep)
+            os.mkdir(dir)
+
     def on_end(self):
-        if self.active:
+        if self.config.profile:
             files = [os.path.join(self.profile_temp_path,file) for file in\
                      os.listdir(self.profile_temp_path)]
-            stats = pstats.Stats(*files,**{'stream':StringIO()})
+            if not files:
+                return
+            stats = pstats.Stats(*files, **{'stream': Stream()})
             stats.sort_stats('time', 'calls')
             stats.print_stats()
             stats_str = stats.stream.getvalue()
             self.remove_dir(self.profile_temp_path)
             stats_str = stats_str.split('\n')
-            run_info = ''
+            run_info = 'Executed %s.' % datetime.now().isoformat()
             for n, line in enumerate(stats_str):
                 b = 0
                 while b < len(line) and line[b] == ' ':
@@ -175,7 +163,7 @@ class Profile(test.Plugin):
                     except:
                         continue
                     else:
-                        run_info = line
+                        run_info += ' ' + line
             data = ''.join(make_stat_table(data_stream(stats_str[n+1:], 100)))
             self.remove_dir(self.profile_stats_path, build=True)
             for file in os.listdir(template_path):
@@ -186,4 +174,3 @@ class Profile(test.Plugin):
                                'version': pulsar.__version__})
                 else:
                     copy_file(file, self.profile_stats_path)
-    
\ No newline at end of file
