@@ -1,11 +1,17 @@
 '''Response middleware
 '''
 import re
+import os
+import stat
+import mimetypes
+from email.utils import parsedate_tz, mktime_tz
 from gzip import GzipFile
 
 import pulsar
 from pulsar.utils.httpurl import BytesIO, parse_authorization_header,\
-                                     parse_cookie
+                                     parse_cookie, http_date
+                                     
+from .wsgi import WsgiResponse
 
 re_accepts_gzip = re.compile(r'\bgzip\b')
 
@@ -15,15 +21,7 @@ __all__ = ['clean_path_middleware',
            'GZipMiddleware',
            'cookies_middleware',
            'authorization_middleware',
-           'is_streamed']
-
-
-def is_streamed(content):
-    try:
-        len(content)
-    except TypeError:
-        return True
-    return False
+           'MediaMiddleware']
 
 
 def clean_path_middleware(environ, start_response):
@@ -134,3 +132,63 @@ base their storage on the Accept-Encoding header.
         return zbuf.getvalue()
 
 
+class MediaMiddleware:
+    DEFAULT_CONTENT_TYPE = 'text/css'
+    def __init__(self, dir_path, url_path='/media/'):
+        self.dir_path = dir_path
+        self.url_path = url_path
+        
+    def __call__(self, environ, start_response):
+        path = environ.get('PATH_INFO')
+        if path.startswith(self.url_path):
+            path = self.dir_path + path[len(self.url_path):]
+            if os.path.isfile(path):
+                response = self.serve_file(environ, path)
+                return response(environ, start_response)
+        
+    def serve_file(self, environ, fullpath):
+        # Respect the If-Modified-Since header.
+        statobj = os.stat(fullpath)
+        content_type, encoding = mimetypes.guess_type(fullpath)
+        content_type = content_type or self.DEFAULT_CONTENT_TYPE
+        if not self.was_modified_since(environ.get('HTTP_IF_MODIFIED_SINCE'),
+                                       statobj[stat.ST_MTIME],
+                                       statobj[stat.ST_SIZE]):
+            return wsgi.WsgiResponse(status=304,
+                                     content_type=content_type,
+                                     encoding=encoding)
+        contents = open(fullpath, 'rb').read()
+        response = wsgi.WsgiResponse(content=contents,
+                                     content_type=content_type,
+                                     encoding=encoding)
+        response.headers["Last-Modified"] = http_date(statobj[stat.ST_MTIME])
+        return response
+    
+    def was_modified_since(self, header=None, mtime=0, size=0):
+        """
+        Was something modified since the user last downloaded it?
+
+        header
+          This is the value of the If-Modified-Since header.  If this is None,
+          I'll just return True.
+
+        mtime
+          This is the modification time of the item we're talking about.
+
+        size
+          This is the size of the item we're talking about.
+        """
+        try:
+            if header is None:
+                raise ValueError
+            matches = re.match(r"^([^;]+)(; length=([0-9]+))?$", header,
+                               re.IGNORECASE)
+            header_mtime = mktime_tz(parsedate_tz(matches.group(1)))
+            header_len = matches.group(3)
+            if header_len and int(header_len) != size:
+                raise ValueError()
+            if mtime > header_mtime:
+                raise ValueError()
+        except (AttributeError, ValueError, OverflowError):
+            return True
+        return False
\ No newline at end of file
