@@ -77,7 +77,8 @@ A typical usage::
 
     
 class Arbiter(PoolMixin, Actor):
-    '''The Arbiter is a special :class:`Monitor`. It is used as singletone
+    '''The Arbiter is the most important a :class:`Actor`
+and :class:`PoolMixin` in pulsar concurrent framework. It is used as singleton
 in the main process and it manages one or more :class:`Monitor`.
 It runs the main :class:`IOLoop` of your concurrent application.
 It is the equivalent of the gunicorn_ arbiter, the twisted_ reactor
@@ -156,8 +157,6 @@ Users access the arbiter (in the arbiter process domain) by the high level api::
             raise pulsar.PulsarException(
                     'Cannot create the arbiter in a daemon process')
         os.environ["SERVER_SOFTWARE"] = pulsar.SERVER_SOFTWARE
-        if self.cfg.daemon: #pragma    nocover
-            system.daemonize()
         pidfile = self.cfg.pidfile
         if pidfile is not None:
             p = Pidfile(pidfile)
@@ -213,6 +212,12 @@ Users access the arbiter (in the arbiter process domain) by the high level api::
     ############################################################################
     # INTERNALS
     ############################################################################
+    def start(self):
+        if self.state == ACTOR_STATES.INITIAL:
+            if self.cfg.daemon: #pragma    nocover
+                system.daemonize()
+            return Actor.start(self)
+            
     def _run(self):
         try:
             self.cfg.when_ready(self)
